@@ -17,6 +17,11 @@
  *************************************************************************************/
 
 #include <QGuiApplication>
+#ifdef Q_OS_ANDROID
+#include <QQuickStyle>
+#else
+#include <QApplication>
+#endif
 
 #include <KLocalizedContext>
 #include <KLocalizedString>
@@ -35,15 +40,18 @@
 
 #include "kalgebramobile.h"
 #include "kalgebra_version.h"
-#include "pluginsmodel.h"
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
-#ifdef __ANDROID__
-    qputenv("QT_QUICK_CONTROLS_STYLE", "Material");
+#ifdef Q_OS_ANDROID
+    QQuickStyle::setStyle("Material");
 #endif
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
+#else
+    QApplication app(argc, argv);
+#endif
     KLocalizedString::setApplicationDomain("kalgebramobile");
     KAboutData about(QStringLiteral("kalgebramobile"), QStringLiteral("KAlgebra"), QStringLiteral(KALGEBRA_VERSION_STRING), i18n("A portable calculator"),
              KAboutLicense::GPL, i18n("(C) 2006-2020 Aleix Pol i Gonzalez"));
@@ -57,21 +65,13 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         parser.process(app);
         about.processCommandLine(&parser);
     }
-    
+
     KAlgebraMobile widget;
-    
-    const QString pluginsDir = PluginsModel::pluginsDirectoryPath();
 
     QQmlApplicationEngine engine;
 
-    engine.rootContext()->setContextProperty(QStringLiteral("app"), &widget);
-    engine.addImportPath(pluginsDir);
-#ifdef __ANDROID__
-    engine.addImportPath(QStringLiteral("assets:/qml"));
-#endif
-
+    qmlRegisterSingletonInstance("org.kde.kalgebra.mobile", 1, 0, "App", &widget);
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-
-    engine.load(QUrl::fromLocalFile(pluginsDir + QStringLiteral("/widgets/KAlgebraMobile.qml")));
+    engine.load(QUrl(QStringLiteral("qrc:/main.qml")));
     return app.exec();
 }
